@@ -6,7 +6,7 @@ use crate::onto::datatype::Lang;
 use crate::onto::individual::{Individual, RawObj};
 use crate::onto::individual2msgpack::to_msgpack;
 use crate::onto::parser::parse_raw;
-use crate::storage::storage::{StorageId, VStorage};
+use crate::storage::common::{StorageId, VStorage};
 use crate::v_api::api_client::IndvOp;
 use crate::v_api::obj::ResultCode;
 use chrono::{Local, NaiveDateTime, Utc};
